/*
 * Copyright (C) 2016 Naoghuman
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package com.github.naoghuman.lib.tile.transparenttextures;

import com.github.naoghuman.lib.tile.core.Tile;

/**
 * The <code>enum</code> TransparentTexturesTile is a collection from 
 * {@link com.github.naoghuman.lib.tile.core.Tile}s which representated the 
 * <code>Tileset</code> from the internet page https://www.transparenttextures.com/.
 * <p />
 * The individual {@link com.github.naoghuman.lib.tile.core.Tile} can be loaded 
 * with the class {@link com.github.naoghuman.lib.tile.transparenttextures.images.TransparentTexturesTileLoader} 
 * from the associated library <code>Lib-Tile-TransparentTextures-Images</code>.
 *
 * @author Naoghuman
 * @see com.github.naoghuman.lib.tile.core.Tile
 * @see com.github.naoghuman.lib.tile.transparenttextures.images.TransparentTexturesTileLoader
 */
public enum TransparentTexturesTile implements Tile {

    /**
     * The <code>Java</code> representation from the tile: 3Px Tile
     */
    TT_3PX_TILE("tt-3px-tile.png", "3Px Tile", 100, 100, "Gre3g", "http://gre3g.livejournal.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: 45 Degree Fabric (Dark)
     */
    TT_45_DEGREE_FABRIC_DARK("tt-45-degree-fabric-dark.png", "45 Degree Fabric (Dark)", 315, 315, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: 45 Degree Fabric (Light)
     */
    TT_45_DEGREE_FABRIC_LIGHT("tt-45-degree-fabric-light.png", "45 Degree Fabric (Light)", 315, 315, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: 60° lines
     */
    TT_60_LINES("tt-60-lines.png", "60° lines", 31, 31, "Atle Mo", "http://atle.co/"), // NOI18N

    /**
     * The <code>Java</code> representation from the tile: Absurdity
     */
    TT_ABSURDITY("tt-absurdity.png", "Absurdity", 4, 4, "Carlos Valdez", "http://saveder.blogspot.de/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: AG Square
     */
    TT_AG_SQUARE("tt-ag-square.png", "AG Square", 50, 50, "Erikdel", "http://www.erikdel.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Always Grey
     */
    TT_ALWAYS_GREY("tt-always-grey.png", "Always Grey", 35, 35, "Stefan Aleksic", "http://www.facebook.com/stefanaleksic88"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Arabesque
     */
    TT_ARABESQUE("tt-arabesque.png", "Arabesque", 110, 110, "David Sanchez", "http://www.twitter.com/davidsancar"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Arches
     */
    TT_ARCHES("tt-arches.png", "Arches", 103, 23, "Kim Ruddock"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Argyle
     */
    TT_ARGYLE("tt-argyle.png", "Argyle", 106, 96, "Will Monson"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Asfalt (Dark)
     */
    TT_ASFALT_DARK("tt-asfalt-dark.png", "Asfalt (Dark)", 466, 349, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Asfalt (Light)
     */
    TT_ASFALT_LIGHT("tt-asfalt-light.png", "Asfalt (Light)", 466, 349, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Assault
     */
    TT_ASSAULT("tt-assault.png", "Assault", 154, 196, "Hendrik Lammers", "http://www.hendriklammers.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Axiom Pattern
     */
    TT_AXIOM_PATTERN("tt-axiom-pattern.png", "Axiom Pattern", 81, 81, "Struck Axiom", "http://struck.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Az Subtle
     */
    TT_AZ_SUBTLE("tt-az-subtle.png", "Az Subtle", 100, 100, "Anli.", "http://azmind.com/"), // NOI18N

    /**
     * The <code>Java</code> representation from the tile: Back Pattern
     */
    TT_BACK_PATTERN("tt-back-pattern.png", "Back Pattern", 28, 28, "M"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Basketball
     */
    TT_BASKETBALL("tt-basketball.png", "Basketball", 227, 196, "Mike Hearn", "https://www.mikehearn.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Batthern
     */
    TT_BATTHERN("tt-batthern.png", "Batthern", 100, 99, "Factorio.us Collective", "http://www.factorious.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Bedge Grunge
     */
    TT_BEDGE_GRUNGE("tt-bedge-grunge.png", "Bedge Grunge", 588, 375, "Alex Tapein", "http://www.tapein.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Beige Paper
     */
    TT_BEIGE_PAPER("tt-beige-paper.png", "Beige Paper", 200, 200, "Konstantin Ivanov", "http://twitter.com/phenix_h_k"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Billie Holiday
     */
    TT_BILLIE_HOLIDAY("tt-billie-holiday.png", "Billie Holiday", 100, 100, "Thomas Myrman", "http://thomasmyrman.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Binding Dark
     */
    TT_BINDING_DARK("tt-binding-dark.png", "Binding Dark", 180, 180, "Tia Newbury"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Binding Light
     */
    TT_BINDING_LIGTH("tt-binding-light.png", "Binding Light", 180, 180, "Tia Newbury"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Black Felt
     */
    TT_BLACK_FELT("tt-black-felt.png", "Black Felt", 531, 337, "E. van Zummeren", "http://evanzummeren.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Black Linen
     */
    TT_BLACK_LINEN_1("tt-black-linen-1.png", "Black Linen", 482, 490, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Black Linen 2
     */
    TT_BLACK_LINEN_2("tt-black-linen-2.png", "Black Linen 2", 640, 640, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Black Mamba
     */
    TT_BLACK_MAMBA("tt-black-mamba.png", "Black Mamba", 192, 192, "Federica Pelzel", "https://about.me/federicca"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Black Orchid"
     */
    TT_BLACK_ORCHID("tt-black-orchid.png", "Black Orchid", 300, 300, "Hybridixstudio", "https://www.hybridixstudio.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Black Paper"
     */
    TT_BLACK_PAPER("tt-black-paper.png", "Black Paper", 400, 400, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Black Scales
     */
    TT_BLACK_SCALES("tt-black-scales.png", "Black Scales", 40, 40, "Alex Parker", "http://twitter.com/misterparker"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Black Thread
     */
    TT_BLACK_THREAD("tt-black-thread.png", "Black Thread", 49, 28, "Listvetra", "http://www.listvetra.ru/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Black Thread (Light)
     */
    TT_BLACK_THREAD_LIGHT("tt-black-thread-light.png", "Black Thread (Light)", 49, 28, "Listvetra", "http://www.listvetra.ru/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Black Twill
     */
    TT_BLACK_TWILL("tt-black-twill.png", "Black Twill", 14, 14, "Cary Fleming"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Blizzard
     */
    TT_BLIZZARD("tt-blizzard.png", "Blizzard", 25, 25, "Alexandre Naud", "http://www.alexandrenaud.fr/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Blu Stripes
     */
    TT_BLU_STRIPES("tt-blu-stripes.png", "Blu Stripes", 100, 100, "Seb Jachec", "http://twitter.com/iamsebj"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Bo Play
     */
    TT_BO_PLAY("tt-bo-play.png", "Bo Play", 42, 22, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Brick Wall
     */
    TT_BRICK_WALL("tt-brick-wall.png", "Brick Wall", 110, 69, "Benjamin Ward"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Brick Wall (Dark)
     */
    TT_BRICK_WALL_DARK("tt-brick-wall-dark.png", "Brick Wall (Dark)", 110, 69, "Benjamin Ward"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Bright Squares
     */
    TT_BRIGHT_SQUARES("tt-bright-squares.png", "Bright Squares", 297, 297, "Waseem Dahman", "http://twitter.com/dwaseem"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Brilliant
     */
    TT_BRILLIANT("tt-brilliant.png", "Brilliant", 3, 3, "Carlos Valdez", "http://saveder.blogspot.de/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Broken Noise
     */
    TT_BROKEN_NOISE("tt-broken-noise.png", "Broken Noise", 476, 476, "Vincent Klaiber", "http://vincentklaiber.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Brushed Alum
     */
    TT_BRUSHED_ALUM("tt-brushed-alum.png", "Brushed Alum", 400, 400, "Tim Ward", "http://www.MentalWardDesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Brushed Alum Dark
     */
    TT_BRUSHED_ALUM_DARK("tt-brushed-alum-dark.png", "Brushed Alum Dark", 400, 400, "Tim Ward", "http://www.MentalWardDesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Buried
     */
    TT_BURIED("tt-buried.png", "Buried", 350, 350, "Hendrik Lammers", "http://www.hendriklammers.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Candyhole
     */
    TT_CANDYHOLE("tt-candyhole.png", "Candyhole", 25, 25, "Josh Green", "https://joshgreendesign.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Carbon Fibre
     */
    TT_CARBON_FIBRE("tt-carbon-fibre.png", "Carbon Fibre", 24, 22, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Carbon Fibre Big
     */
    TT_CARBON_FIBRE_BIG("tt-carbon-fibre-big.png", "Carbon Fibre Big", 20, 22, "Factorio.us Collective", "http://www.factorious.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Carbon Fibre V2
     */
    TT_CARBON_FIBRE_V2("tt-carbon-fibre-v2.png", "Carbon Fibre V2", 32, 36, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Cardboard
     */
    TT_CARDBOARD("tt-cardboard.png", "Cardboard", 600, 600, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Cardboard Flat
     */
    TT_CARDBOARD_FLAT("tt-cardboard-flat.png", "Cardboard Flat", 256, 256, "Appleshadow"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Cartographer
     */
    TT_CARTOGRAPHER("tt-cartographer.png", "Cartographer", 500, 499, "Sam Feyaerts", "http://sam.feyaerts.me/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Checkered Light Emboss
     */
    TT_CHECKERED_LIGHT_EMBOSS("tt-checkered-light-emboss.png", "Checkered Light Emboss", 60, 60, "Alex Parker", "https://twitter.com/misterparker"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Checkered Pattern
     */
    TT_CHECKERED_PATTERN("tt-checkered-pattern.png", "Checkered Pattern", 72, 72, "Radoslaw Rzepecki", "http://designcocktails.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Church
     */
    TT_CHURCH("tt-church.png", "Church", 100, 100, "j Boo"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Circles
     */
    TT_CIRCLES("tt-circles.png", "Circles", 16, 22, "Blunia", "http://www.es.blunia.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Classy Fabric
     */
    TT_CLASSY_FABRIC("tt-classy-fabric.png", "Classy Fabric", 102, 102, "Richard Tabor", "http://purtypixels.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Clean Gray Paper
     */
    TT_CLEAN_GRAY_PAPER("tt-clean-gray-paper.png", "Clean Gray Paper", 512, 512, "Paul Phönixweiß", "http://phoenixweiss.me"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Clean Textile
     */
    TT_CLEAN_TEXTILE("tt-clean-textile.png", "Clean Textile", 420, 420, "N8rx"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Climpek
     */
    TT_CLIMPEK("tt-climpek.png", "Climpek", 44, 44, "Wassim", "http://www.blugraphic.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Cloth Alike
     */
    TT_CLOTH_ALIKE("tt-cloth-alike.png", "Cloth Alike", 102, 78, "Peax Webdesign", "http://www.peax-webdesign.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Concrete Wall
     */
    TT_CONCRETE_WALL("tt-concrete-wall.png", "Concrete Wall", 520, 520, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Concrete Wall 2
     */
    TT_CONCRETE_WALL_2("tt-concrete-wall-2.png", "Concrete Wall 2", 597, 545, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Concrete Wall 3
     */
    TT_CONCRETE_WALL_3("tt-concrete-wall-3.png", "Concrete Wall 3", 400, 299, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Connected
     */
    TT_CONNECTED("tt-connected.png", "Connected", 160, 160, "Mark Collins", "http://pixxel.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Corrugation
     */
    TT_CORRUGATION("tt-corrugation.png", "Corrugation", 8, 5, "Anna Litvinuk", "https://graphicriver.net/user/annalitviniuk"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Cream Dust
     */
    TT_CREAM_DUST("tt-cream-dust.png", "Cream Dust", 50, 50, "Thomas Myrman", "http://thomasmyrman.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Cream Paper
     */
    TT_CREAM_PAPER("tt-cream-paper.png", "Cream Paper", 158, 144, "Devin Holmes", "http://www.strick9design.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Cream Pixels
     */
    TT_CREAM_PIXELS("tt-cream-pixels.png", "Cream Pixels", 160, 160, "Mizanur Rahman", "https://www.behance.net/rexmizan"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Crisp Paper Ruffles
     */
    TT_CRISP_PAPER_RUFFLES("tt-crisp-paper-ruffles.png", "Crisp Paper Ruffles", 481, 500, "Tish"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Crissxcross
     */
    TT_CRISSXCROSS("tt-crissxcross.png", "Crissxcross", 512, 512, "Ashton"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Crossword
     */
    TT_CROSSWORD("tt-crossword.png", "Crossword", 400, 400, "Ideawebme", "http://www.ideaweb.me/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Cross Scratches
     */
    TT_CROSS_SCRATCHES("tt-cross-scratches.png", "Cross Scratches", 256, 256, "Andrey Ovcharov", "https://www.ovcharov.me/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Cross Stripes
     */
    TT_CROSS_STRIPES("tt-cross-stripes.png", "Cross Stripes", 6, 6, "Stefan Aleksic", "http://www.facebook.com/stefanaleksic88"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Cubes
     */
    TT_CUBES("tt-cubes.png", "Cubes", 67, 100, "Sander Ottens", "http://experimint.nl/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Cutcube
     */
    TT_CUTCUBE("tt-cutcube.png", "Cutcube", 20, 36, "Michael Atkins", "http://cubecolour.co.uk/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Brick Wall
     */
    TT_DARK_BRICK_WALL("tt-dark-brick-wall.png", "Dark Brick Wall", 96, 96, "Alex Parker", "http://www.alexparker.me/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Circles
     */
    TT_DARK_CIRCLES("tt-dark-circles.png", "Dark Circles", 10, 12, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Denim
     */
    TT_DARK_DENIM("tt-dark-denim.png", "Dark Denim", 145, 145, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Denim 3
     */
    TT_DARK_DENIM_3("tt-dark-denim-3.png", "Dark Denim 3", 420, 326, "Brandon Jacoby", "http://www.brandonjacoby.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Dot
     */
    TT_DARK_DOT("tt-dark-dot.png", "Dark Dot", 5, 5, "Tsvetelin Nikolov", "https://dribbble.com/bscsystem"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Dotted 2
     */
    TT_DARK_DOTTED_2("tt-dark-dotted-2.png", "Dark Dotted 2", 7, 7, "Venam", "http://venam.1.ai"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Exa
     */
    TT_DARK_EXA("tt-dark-exa.png", "Dark Exa", 18, 30, "Venam", "http://venam.1.ai"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Fish Skin
     */
    TT_DARK_FISH_SKIN("tt-dark-fish-skin.png", "Dark Fish Skin", 6, 12, "Petr Sulc", "http://www.petrsulc.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Geometric
     */
    TT_DARK_GEOMETRIC("tt-dark-geometric.png", "Dark Geometric", 70, 70, "Mike Warner", "http://miketheindian.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Leather
     */
    TT_DARK_LEATHER("tt-dark-leather.png", "Dark Leather", 398, 484, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Matter
     */
    TT_DARK_MATTER("tt-dark-matter.png", "Dark Matter", 7, 7, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Mosaic
     */
    TT_DARK_MOSAIC("tt-dark-mosaic.png", "Dark Mosaic", 300, 295, "John Burks"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Stripes
     */
    TT_DARK_STRIPES("tt-dark-stripes.png", "Dark Stripes", 50, 50, "Stefan Aleksic", "https://www.facebook.com/stefanaleksic88"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Stripes (Light)
     */
    TT_DARK_STRIPES_LIGHT("tt-dark-stripes-light.png", "Dark Stripes (Light)", 50, 50, "Stefan Aleksic", "https://www.facebook.com/stefanaleksic88"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Tire
     */
    TT_DARK_TIRE("tt-dark-tire.png", "Dark Tire", 250, 250, "Wilmotte Bastien", "https://dribbble.com/bastienwilmotte"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Wall
     */
    TT_DARK_WALL("tt-dark-wall.png", "Dark Wall", 300, 300, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dark Wood
     */
    TT_DARK_WOOD("tt-dark-wood.png", "Dark Wood", 512, 512, "Omar Alvarado", "http://www.oaadesigns.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Darth Stripe
     */
    TT_DARTH_STRIPE("tt-darth-stripe.png", "Darth Stripe", 511, 511, "Ashton"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Debut Dark
     */
    TT_DEBUT_DARK("tt-debut-dark.png", "Debut Dark", 200, 200, "Luke McDonald", "https://www.lukemcdonald.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Debut Light
     */
    TT_DEBUT_LIGHT("tt-debut-light.png", "Debut Light", 200, 200, "Luke McDonald", "https://www.lukemcdonald.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Diagmonds (Dark)
     */
    TT_DIAGMONDS_DARK("tt-diagmonds-dark.png", "Diagmonds (Dark)", 141, 142, "INS", "https://www.flickr.com/photos/ins"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Diagmonds (Light)
     */
    TT_DIAGMONDS_LIGHT("tt-diagmonds-light.png", "Diagmonds (Light)", 141, 142, "INS", "https://www.flickr.com/photos/ins"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Diagonales Decalees
     */
    TT_DIAGONALES_DECALEES("tt-diagonales-decalees.png", "Diagonales Decalees", 144, 48, "Graphiste", "http://www.peax-webdesign.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Diagonal Noise
     */
    TT_DIAGONAL_NOISE("tt-diagonal-noise.png", "Diagonal Noise", 100, 100, "Christopher Burton", "http://ChristopherBurton.net"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Diagonal Striped Brick
     */
    TT_DIAGONAL_STRIPED_BRICK("tt-diagonal-striped-brick.png", "Diagonal Striped Brick", 150, 150, "Alex Smith"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Diagonal Waves
     */
    TT_DIAGONAL_WAVES("tt-diagonal-waves.png", "Diagonal Waves", 38, 38, "CoolPatterns", "http://coolpatterns.net/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Diamonds Are Forever
     */
    TT_DIAMONDS_ARE_FOREVER("tt-diamonds-are-forever.png", "Diamonds Are Forever", 24, 18, "Tom Neal", "http://imaketees.co.uk"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Diamond Eyes
     */
    TT_DIAMOND_EYES("tt-diamond-eyes.png", "Diamond Eyes", 33, 25, "AJ Troxell", "http://ajtroxell.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Diamond Upholstery
     */
    TT_DIAMOND_UPHOLSTERY("tt-diamond-upholstery.png", "Diamond Upholstery", 200, 200, "Dimitar Karaytchev"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dimension
     */
    TT_DIMENSION("tt-dimension.png", "Dimension", 43, 50, "Luuk van Baars", "http://luuk.ca/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dirty Old Black Shirt
     */
    TT_DIRTY_OLD_BLACK_SHIRT("tt-dirty-old-black-shirt.png", "Dirty Old Black Shirt", 250, 250, "Paul Reulat", "https://twitter.com/PaulReulat"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dotnoise Light Grey
     */
    TT_DOTNOISE_LIGHT_GREY("tt-dotnoise-light-grey.png", "Dotnoise Light Grey", 100, 100, "Nikolalek"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Double Lined"
     */
    TT_DOUBLE_LINED("tt-double-lined.png", "Double Lined", 150, 64, "Adam Anlauf", "http://www.depcore.pl"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Dust
     */
    TT_DUST("tt-dust.png", "Dust", 400, 300, "Dominik Kiss", "http://werk.sk/w/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Ecailles
     */
    TT_ECAILLES("tt-ecailles.png", "Ecailles", 48, 20, "Graphiste", "http://www.peax-webdesign.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Egg Shell
     */
    TT_EGG_SHELL("tt-egg-shell.png", "Egg Shell", 256, 256, "Paul Phönixweiß", "http://phoenixweiss.me"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Elastoplast
     */
    TT_ELASTOPLAST("tt-elastoplast.png", "Elastoplast", 37, 37, "Josh Green", "https://joshgreendesign.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Elegant Grid
     */
    TT_ELEGANT_GRID("tt-elegant-grid.png", "Elegant Grid", 16, 28, "GraphicsWall", "http://www.graphicswall.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Embossed Paper
     */
    TT_EMBOSSED_PAPER("tt-embossed-paper.png", "Embossed Paper", 8, 10, "Badhon Ebrahim", "http://dribbble.com/graphcoder"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Escheresque
     */
    TT_ESCHERESQUE("tt-escheresque.png", "Escheresque", 46, 29, "Jan Meeus", "https://dribbble.com/janmeeus"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Escheresque Dark
     */
    TT_ESCHERESQUE_DARK("tt-escheresque-dark.png", "Escheresque Dark", 46, 29, "Ste Patten"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Exclusive Paper"
     */
    TT_EXCLUSIVE_PAPER("tt-exclusive-paper.png", "Exclusive Paper", 560, 420, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Fabric 1 (Dark)
     */
    TT_FABRIC_1_DARK("tt-fabric-1-dark.png", "Fabric 1 (Dark)", 400, 400, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Fabric 1 (Light)
     */
    TT_FABRIC_1_LIGHT("tt-fabric-1-light.png", "Fabric 1 (Light)", 400, 400, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Fabric Of Squares
     */
    TT_FABRIC_OF_SQUARES("tt-fabric-of-squares.png", "Fabric Of Squares", 410, 410, "Heliodor Jalba", "https://about.me/heliodor"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Fabric (Plaid)
     */
    TT_FABRIC_PLAID("tt-fabric-plaid.png", "Fabric (Plaid)", 200, 200, "James Basoo", "https://twitter.com/jbasoo"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Fake Brick
     */
    TT_FAKE_BRICK("tt-fake-brick.png", "Fake Brick", 76, 76, "Marat"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Fake Luxury
     */
    TT_FAKE_LUXURY("tt-fake-luxury.png", "Fake Luxury", 16, 26, "Factorio.us Collective", "http://www.factorious.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Fancy Deboss
     */
    TT_FANCY_DEBOSS("tt-fancy-deboss.png", "Fancy Deboss", 18, 13, "Daniel Beaton", "http://danielbeaton.tumblr.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Farmer
     */
    TT_FARMER("tt-farmer.png", "Farmer", 349, 349, "Fabian Schultz", "http://fabianschultz.de"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Felt
     */
    TT_FELT("tt-felt.png", "Felt", 500, 466, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: First Aid Kit
     */
    TT_FIRST_AID_KIT("tt-first-aid-kit.png", "First Aid Kit", 99, 99, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Flowers
     */
    TT_FLOWERS("tt-flowers.png", "Flowers", 150, 150, "Unknown"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Flower Trail
     */
    TT_FLOWER_TRAIL("tt-flower-trail.png", "Flower Trail", 16, 16, "Paridhi"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Foggy Birds"
     */
    TT_FOGGY_BIRDS("tt-foggy-birds.png", "Foggy Birds", 206, 206, "Pete Fecteau", "http://buttonpresser.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Food
     */
    TT_FOOD("tt-food.png", "Food", 300, 300, "Ilya"), // NOI18N
    
    // football-no-lines are 2 pictures (dark-light) tweak it TODO
    /**
     * The <code>Java</code> representation from the tile: Football (No Yardlines)
     */
    TT_FOOTBALL_NO_LINES("tt-football-no-lines.png", "Football (No Yardlines)", 714, 240, "Mike Hearn", "https://www.mikehearn.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: French Stucco
     */
    TT_FRENCH_STUCCO("tt-french-stucco.png", "French Stucco", 400, 355, "Christopher Buecheler", "http://cwbuecheler.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Fresh Snow
     */
    TT_FRESH_SNOW("tt-fresh-snow.png", "Fresh Snow", 500, 500, "Kerstkaarten", "https://www.fotokaarten.nl/kerst.html"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Gold Scale
     */
    TT_GOLD_SCALE("tt-gold-scale.png", "Gold Scale", 25, 25, "Josh Green", "https://joshgreendesign.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Gplay
     */
    TT_GPLAY("tt-gplay.png", "Gplay", 188, 178, "Dimitrie Hoekstra", "http://dhesign.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Gradient Squares
     */
    TT_GRADIENT_SQUARES("tt-gradient-squares.png", "Gradient Squares", 202, 202, "Brankic1979", "http://www.brankic1979.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Graphcoders Lil Fiber
     */
    TT_GRAPHCODERS_LIL_FIBER("tt-graphcoders-lil-fiber.png", "Graphcoders Lil Fiber", 21, 35, "Badhon Ebrahim", "http://dribbble.com/graphcoder"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Graphy (Dark)
     */
    TT_GRAPHY_DARK("tt-graphy-dark.png", "Graphy (Dark)", 80, 160, "We Are Pixel8", "http://www.wearepixel8.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Graphy (Light)
     */
    TT_GRAPHY_LIGHT("tt-graphy-light.png", "Graphy (Light)", 80, 160, "We Are Pixel8", "http://www.wearepixel8.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Gravel
     */
    TT_GRAVEL("tt-gravel.png", "Gravel", 222, 206, "Mike Hearn", "http://www.mikehearn.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Gray Floral
     */
    TT_GRAY_FLORAL("tt-gray-floral.png", "Gray Floral", 150, 124, "Lauren", "http://laurenharrison.org"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Gray Lines
     */
    TT_GRAY_LINES("tt-gray-lines.png", "Gray Lines", 150, 150, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Gray Sand
     */
    TT_GRAY_SAND("tt-gray-sand.png", "Gray Sand", 211, 211, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Green Cup
     */
    TT_GREEN_CUP("tt-green-cup.png", "Green Cup", 400, 400, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Green Dust and Scratches
     */
    TT_GREEN_DUST_AND_SCRATCHES("tt-green-dust-and-scratches.png", "Green Dust and Scratches", 296, 300, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Green Fibers
     */
    TT_GREEN_FIBERS("tt-green-fibers.png", "Green Fibers", 200, 200, "Matteo Di Capua", "http://www.matteodicapua.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Green Gobbler
     */
    TT_GREEN_GOBBLER("tt-green-gobbler.png", "Green Gobbler", 39, 39, "Simon Meek", "http://www.simonmeek.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Greyzz
     */
    TT_GREYZZ("tt-greyzz.png", "Greyzz", 149, 139, "Infographiste", "http://www.peax-webdesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Grey Jean
     */
    TT_GREY_JEAN("tt-grey-jean.png", "Grey Jean", 150, 150, "Omur Uluask", "http://mr.pn"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Grey Sandbag
     */
    TT_GREY_SANDBAG("tt-grey-sandbag.png", "Grey Sandbag", 100, 98, "Diogo Silva", "http://www.diogosilva.net"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Grey Washed Wall
     */
    TT_GREY_WASHED_WALL("tt-grey-washed-wall.png", "Grey Washed Wall", 350, 259, "Sagive SEO", "http://www.sagive.co.il"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Grid
     */
    TT_GRID("tt-grid.png", "Grid", 310, 310, "Dominik Kiss", "http://www.werk.sk"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Grid Me
     */
    TT_GRID_ME("tt-grid-me.png", "Grid Me", 50, 50, "Arno Gregorian", "http://www.gobigbang.nl"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Grid Noise
     */
    TT_GRID_NOISE("tt-grid-noise.png", "Grid Noise", 98, 98, "Daivid Serif"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Grilled Noise
     */
    TT_GRILLED_NOISE("tt-grilled-noise.png", "Grilled Noise", 170, 180, "Dertig Media", "http://30.nl"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Groovepaper
     */
    TT_GROOVEPAPER("tt-groovepaper.png", "Groovepaper", 300, 300, "Isaac", "http://graphicriver.net/user/krispdesigns"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Grunge Wall
     */
    TT_GRUNGE_WALL("tt-grunge-wall.png", "Grunge Wall", 500, 375, "Adam Anlauf", "http://www.depcore.pl"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Gun Metal
     */
    TT_GUN_METAL("tt-gun-metal.png", "Gun Metal", 10, 10, "Nikolay Boltachev", "http://www.zigzain.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Handmade Paper
     */
    TT_HANDMADE_PAPER("tt-handmade-paper.png", "Handmade Paper", 100, 100, "Le Marquis"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Hexabump
     */
    TT_HEXABUMP("tt-hexabump.png", "Hexabump", 19, 33, "Norbert Levajsics", "http://spom.me"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Hexellence
     */
    TT_HEXELLENCE("tt-hexellence.png", "Hexellence", 150, 173, "Kim Ruddock", "http://www.webdesigncreare.co.uk"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Hixs Evolution
     */
    TT_HIXS_EVOLUTION("tt-hixs-evolution.png", "Hixs Evolution", 35, 34, "Damian Rivas", "http://www.hybridixstudio.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Hoffman
     */
    TT_HOFFMAN("tt-hoffman.png", "Hoffman", 16, 16, "Josh Green", "https://joshgreendesign.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Honey I'm Subtle
     */
    TT_HONEY_IM_SUBTLE("tt-honey-im-subtle.png", "Honey I'm Subtle", 179, 132, "Alex M. Balling", "http://www.blof.dk"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Ice Age
     */
    TT_ICE_AGE("tt-ice-age.png", "Ice Age", 400, 400, "Gjermund Gustavsen", "http://tight.no"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Inflicted
     */
    TT_INFLICTED("tt-inflicted.png", "Inflicted", 240, 240, "Hugo Loning", "http://www.inflicted.nl"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Inspiration Geometry
     */
    TT_INSPIRATION_GEOMETRY("tt-inspiration-geometry.png", "Inspiration Geometry", 412, 412, "Welsley", "http://www.pdmb.org/work"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Iron Grip
     */
    TT_IRON_GRIP("tt-iron-grip.png", "Iron Grip", 300, 301, "Tony Kinard", "http://www.tonykinard.net"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Kinda Jean
     */
    TT_KINDA_JEAN("tt-kinda-jean.png", "Kinda Jean", 147, 147, "Graphiste", "http://www.peax-webdesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Knitted Netting
     */
    TT_KNITTED_NETTING("tt-knitted-netting.png", "Knitted Netting", 8, 8, "Anna Litvinuk", "http://graphicriver.net/user/Naf_Naf?ref=Naf_Naf"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Knitted Sweater
     */
    TT_KNITTED_SEATER("tt-knitted-sweater.png", "Knitted Sweater", 250, 250, "Victoria Spahn", "https://twitter.com/VictoriaSpahn"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Kuji
     */
    TT_KUJI("tt-kuji.png", "Kuji", 30, 30, "Josh Green", "https://joshgreendesign.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Large Leather
     */
    TT_LARGE_LEATHER("tt-large-leather.png", "Large Leather", 400, 343, "Elemis", "http://elemisfreebies.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Leather
     */
    TT_LEATHER("tt-leather.png", "Leather", 300, 300, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Light Aluminum
     */
    TT_LIGHT_ALUMINUM("tt-light-aluminum.png", "Light Aluminum", 282, 282, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Light Gray
     */
    TT_LIGHT_GRAY("tt-light-gray.png", "Light Gray", 301, 621, "Brenda Lay", "http://poisones.tumblr.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Light Grey Floral Motif
     */
    TT_LIGHT_GREY_FLORAL_MOTIF("tt-light-grey-floral-motif.png", "Light Grey Floral Motif", 32, 56, "GraphicsWall", "http://www.graphicswall.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Light Honeycomb
     */
    TT_LIGHT_HONEYCOMB("tt-light-honeycomb.png", "Light Honeycomb", 270, 289, "Federica Pelzel", "http://about.me/federicca"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Light Honeycomb (Dark)
     */
    TT_LIGHT_HONEYCOMB_DARK("tt-light-honeycomb-dark.png", "Light Honeycomb (Dark)", 270, 289, "Federica Pelzel", "http://about.me/federicca"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Light Mesh
     */
    TT_LIGHT_MESH("tt-light-mesh.png", "Light Mesh", 256, 256, "Wilmotte Bastien", "http://dribbble.com/bastienwilmotte"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Light Paper Fibers
     */
    TT_LIGHT_PAPER_FIBERS("tt-light-paper-fibers.png", "Light Paper Fibers", 500, 300, "Jorge Fuentes", "http://www.jorgefuentes.net"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Light Sketch
     */
    TT_LIGHT_SKETCH("tt-light-sketch.png", "Light Sketch", 600, 600, "Dan Kruse", "http://dankruse.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Light Toast
     */
    TT_LIGHT_TOAST("tt-light-toast.png", "Light Toast", 200, 200, "Pippin Lee", "https://twitter.com/#!/pippinlee"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Light Wool
     */
    TT_LIGHT_WOOL("tt-light-wool.png", "Light Wool", 190, 191, "Andy", "http://www.tall.me.uk"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Lined Paper
     */
    TT_LINED_PAPER("tt-lined-paper.png", "Lined Paper", 300, 224, "Are Sundnes", "http://www.paranaiv.no"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Lined Paper 2
     */
    TT_LINED_PAPER_2("tt-lined-paper-2.png", "Lined Paper 2", 412, 300, "Gjermund Gustavsen", "http://www.tight.no"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Little Knobs
     */
    TT_LITTLE_KNOBS("tt-little-knobs.png", "Little Knobs", 10, 10, "Amos", "http://www.freepx.net"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Little Pluses
     */
    TT_LITTLE_PLUSES("tt-little-pluses.png", "Little Pluses", 300, 300, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Little Triangles
     */
    TT_LITTLE_TRIANGLES("tt-little-triangles.png", "Little Triangles", 10, 11, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Low Contrast Linen
     */
    TT_LOW_CONTRAST_LINEN("tt-low-contrast-linen.png", "Low Contrast Linen", 256, 256, "Jordan Pittman"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Lyonnette
     */
    TT_LYONNETTE("tt-lyonnette.png", "Lyonnette", 90, 90, "Tish", "http://www.ayonnette.blogspot.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Maze Black
     */
    TT_MAZE_BLACK("tt-maze-black.png", "Maze Black", 46, 23, "Peax", "http://www.peax-webdesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Maze White
     */
    TT_MAZE_WHITE("tt-maze-white.png", "Maze White", 46, 23, "Peax", "http://www.peax-webdesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Mbossed
     */
    TT_MBOSSED("tt-mbossed.png", "Mbossed", 26, 26, "Alex Parker", "http://twitter.com/misterparker"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Medic Packaging Foil
     */
    TT_MEDIC_PACKAGING_FOIL("tt-medic-packaging-foil.png", "Medic Packaging Foil", 8, 8, "pixilated", "http://be.net/pixilated"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Merely Cubed
     */
    TT_MERELY_CUBED("tt-merely-cubed.png", "Merely Cubed", 16, 16, "Etienne Rallion", "http://www.etiennerallion.fr"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Micro Carbon
     */
    TT_MICRO_CARBON("tt-micro-carbon.png", "Micro Carbon", 4, 4, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Mirrored Squares
     */
    TT_MIRRORED_SQUARES("tt-mirrored-squares.png", "Mirrored Squares", 166, 166, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Mocha Grunge
     */
    TT_MOCHA_GRUNGE("tt-mocha-grunge.png", "Mocha Grunge", 400, 400, "Joel Klein", "http://www.evelt.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Mooning
     */
    TT_MOONING("tt-mooning.png", "Mooning", 400, 400, "Joel Klein", "http://www.evelt.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Moulin
     */
    TT_MOULING("tt-moulin.png", "Moulin", 20, 20, "Venam", "http://venam.1.ai"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: My Little Plaid (Dark)
     */
    TT_MY_LITTLE_PLAID_DARK("tt-my-little-plaid-dark.png", "My Little Plaid (Dark)", 54, 54, "Pete Fecteau", "http://buttonpresser.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: My Little Plaid (Light)
     */
    TT_MY_LITTLE_PLAID_LIGHT("tt-my-little-plaid-light.png", "My Little Plaid (Light)", 54, 54, "Pete Fecteau", "http://buttonpresser.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Nami
     */
    TT_NAMI("tt-nami.png", "Nami", 16, 16, "Dertig Media", "http://30.nl"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Nasty Fabric
     */
    TT_NASTY_FABRIC("tt-nasty-fabric.png", "Nasty Fabric", 198, 200, "Badhon Ebrahim", "http://dribbble.com/graphcoder"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Natural Paper
     */
    TT_NATURAL_PAPER("tt-natural-paper.png", "Natural Paper", 523, 384, "Mihaela Hinayon"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Navy
     */
    TT_NAVY("tt-navy.png", "Navy", 600, 385, "Ethan Hamilton", "http://ultranotch.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Nice Snow
     */
    TT_NICE_SNOW("tt-nice-snow.png", "Nice Snow", 250, 250, "Kerstkaarten", "http://www.fotokaarten.nl/kerst.html"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Nistri
     */
    TT_NISTRI("tt-nistri.png", "Nistri", 38, 38, "Markus Reiter", "http://reitermark.us/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Noise Lines
     */
    TT_NOISE_LINES("tt-noise-lines.png", "Noise Lines", 60, 59, "Thomas Zucx"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Noise Pattern With Subtle Cross Lines
     */
    TT_NOISE_PATTERN_WITH_SUBTLE_CROSS_LINES("tt-noise-pattern-with-subtle-cross-lines.png", "Noise Pattern With Subtle Cross Lines", 240, 240, "Viszt Peter", ""), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Noisy
     */
    TT_NOISY("tt-noisy.png", "Noisy", 300, 300, "Mladjan Antic", "http://anticdesign.info/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Noisy Grid
     */
    TT_NOISY_GRID("tt-noisy-grid.png", "Noisy Grid", 150, 150, "Vectorpile", "http://www.vectorpile.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Noisy Net
     */
    TT_NOISY_NET("tt-noisy-net.png", "Noisy Net", 200, 200, "Tom McArdle", "http://twitter.com/_mcrdl"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Norwegian Rose"
     */
    TT_NORWEGIAN_ROSE("tt-norwegian-rose.png", "Norwegian Rose", 48, 48, "Fredrik Scheide"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Notebook
     */
    TT_NOTEBOOK("tt-notebook.png", "Notebook", 300, 154, "HQvectors", "http://www.hqvectors.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Notebook (Dark)
     */
    TT_NOTEBOOK_DARK("tt-notebook-dark.png", "Notebook (Dark)", 300, 154, "HQvectors", "http://www.hqvectors.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Office
     */
    TT_OFFICE("tt-office.png", "Office", 70, 70, "Andres Rigo", "http://www.andresrigo.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Old Husks
     */
    TT_OLD_HUSKS("tt-old-husks.png", "Old Husks", 500, 500, "Josh Green", "https://joshgreendesign.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Old Map
     */
    TT_OLD_MAP("tt-old-map.png", "Old Map", 256, 256, "Andreas Föhl", "http://www.netzfeld.de"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Old Mathematics
     */
    TT_OLD_MATHEMATICS("tt-old-mathematics.png", "Old Mathematics", 200, 200, "Josh Green", "https://joshgreendesign.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Old Moon
     */
    TT_OLD_MOON("tt-old-moon.png", "Old Moon", 300, 300, "Nick Batchelor", "http://www.italicsbold.com.au"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Old Wall
     */
    TT_OLD_WALL("tt-old-wall.png", "Old Wall", 300, 300, "Bartosz Kaszubowski", "http://twitter.com/simek"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Otis Redding
     */
    TT_OTIS_REDDING("tt-otis-redding.png", "Otis Redding", 100, 100, "Thomas Myrman", "http://thomasmyrman.com\""), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Outlets
     */
    TT_OUTLETS("tt-outlets.png", "Outlets", 4, 8, "Michal Chovanec", "http://michalchovanec.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: P1
     */
    TT_P1("tt-p1.png", "P1", 8, 9, "Dima Shiper", "http://www.epictextures.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: P2
     */
    TT_P2("tt-p2.png", "P2", 4, 5, "Dima Shiper", "http://www.epictextures.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: P4
     */
    TT_P4("tt-p4.png", "P4", 8, 8, "Dima Shiper", "http://www.epictextures.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: P5
     */
    TT_P5("tt-p5.png", "P5", 8, 8, "Dima Shiper", "http://www.epictextures.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: P6
     */
    TT_P6("tt-p6.png", "P6", 8, 8, "Dima Shiper", "http://www.epictextures.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Padded
     */
    TT_PADDED("tt-padded.png", "Padded", 160, 160, "Chris Baldie", "http://papertank.co.uk"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Padded (Light)
     */
    TT_PADDED_LIGHT("tt-padded-light.png", "Padded (Light)", 160, 160, "Chris Baldie", "http://papertank.co.uk"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Paper
     */
    TT_PAPER("tt-paper.png", "Paper", 500, 593, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Paper 1
     */
    TT_PAPER_1("tt-paper-1.png", "Paper 1", 400, 400, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Paper 2
     */
    TT_PAPER_2("tt-paper-2.png", "Paper 2", 280, 280, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Paper 3
     */
    TT_PAPER_3("tt-paper-3.png", "Paper 3", 276, 276, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Paper Fibers
     */
    TT_PAPER_FIBERS("tt-paper-fibers.png", "Paper Fibers", 410, 410, "Heliodor jalba", "http://about.me/heliodor"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Josh Green
     */
    TT_PAVEN("tt-paven.png", "Paven", 20, 20, "Josh Green", "https://joshgreendesign.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Perforated White Leather
     */
    TT_PERFORATED_WHITE_LEATHER("tt-perforated-white-leather.png", "Perforated White Leather", 300, 300, "Dmitry"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Pineapple Cut
     */
    TT_PINEAPPLE_CUT("tt-pineapple-cut.png", "Pineapple Cut", 36, 62, "Audee Mirza", "http://audeemirza.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Pinstriped Suit
     */
    TT_PINSTRIPED_SUIT("tt-pinstriped-suit.png", "Pinstriped Suit", 400, 333, "Alex Berkowitz", "http://www.alexberkowitz.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Pinstripe (Dark)
     */
    TT_PINSTRIPE_DARK("tt-pinstripe-dark.png", "Pinstripe (Dark)", 50, 500, "Brandon", "http://extrast.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Pinstripe (Light)
     */
    TT_PINSTRIPE_LIGHT("tt-pinstripe-light.png", "Pinstripe (Light)", 50, 500, "Brandon", "http://extrast.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Pixel Weave
     */
    TT_PIXEL_WEAVE("tt-pixel-weave.png", "Pixel Weave", 64, 64, "Dax Kieran", "http://daxkieran.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Polaroid
     */
    TT_POLAROID("tt-polaroid.png", "Polaroid", 58, 36, "Daniel Beaton", "http://danielbeaton.tumblr.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Polonez Pattern
     */
    TT_POLONEZ_PATTERN("tt-polonez-pattern.png", "Polonez Pattern", 300, 300, "Radoslaw Rzepecki", "Radoslaw Rzepecki"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Polyester Lite
     */
    TT_POLYESTER_LITE("tt-polyester-lite.png", "Polyester Lite", 17, 22, "Jeremy", "http://dribbble.com/jeremyelder"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Pool Table
     */
    TT_POOL_TABLE("tt-pool-table.png", "Pool Table", 256, 256, "Caveman", "http://caveman.chlova.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Project Paper
     */
    TT_PROJECT_PAPER("tt-project-paper.png", "Project Paper", 105, 105, "Rafael Almeida", "http://www.fotografiaetc.com.br/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Psychedelic
     */
    TT_PSYCHEDELIC("tt-psychedelic.png", "Psychedelic", 84, 72, "Pixeden", "http://www.pixeden.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Ps Neutral
     */
    TT_PS_NEUTRAL("tt-ps-neutral.png", "Ps Neutral", 16, 16, "Gluszczenko", "http://www.gluszczenko.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Purty Wood
     */
    TT_PURTY_WOOD("tt-purty-wood.png", "Purty Wood", 400, 400, "Richard Tabor", "http://www.purtypixels.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Pw Pattern
     */
    TT_PW_PATTERN("tt-pw-pattern.png", "Pw Pattern", 188, 188, "Peax", "http://www.peax-webdesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Pyramid
     */
    TT_PYRAMID("tt-pyramid.png", "Pyramid", 16, 16, "Jeff Wall"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Josh Green
     */
    TT_QUILT("tt-quilt.png", "Quilt", 25, 24, "Josh Green", "https://joshgreendesign.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Random Grey Variations
     */
    TT_RANOM_GREY_VARIATIONS("tt-random-grey-variations.png", "Random Grey Variations", 200, 200, "Stefan Aleksic", "http://www.MentalWardDesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Ravenna
     */
    TT_RAVENNA("tt-ravenna.png", "Ravenna", 387, 201, "Sentel", "http://sentel.co"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Real Carbon Fibre
     */
    TT_REAL_CARBON_FIBRE("tt-real-carbon-fibre.png", "Real Carbon Fibre", 56, 56, "Alfred Lee"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Rebel
     */
    TT_REBEL("tt-rebel.png", "Rebel", 320, 360, "Hendrik Lammers", "http://www.hendriklammers.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Redox 01
     */
    TT_REDOX_01("tt-redox-01.png", "Redox 01", 600, 375, "Hendrik Lammers", "http://www.hendriklammers.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Redox 02
     */
    TT_REDOX_02("tt-redox-02.png", "Redox 02", 600, 340, "Hendrik Lammers", "http://www.hendriklammers.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Reticular Tissue
     */
    TT_RETICULAR_TISSUE("tt-reticular-tissue.png", "Reticular Tissue", 25, 25, "Anna Litvinuk", "http://graphicriver.net/user/Naf_Naf?ref=Naf_Naf"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Retina Dust
     */
    TT_RETINA_DUST("tt-retina-dust.png", "Retina Dust", 200, 200, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Retina Wood
     */
    TT_RETINA_WOOD("tt-retina-wood.png", "Retina Wood", 512, 512, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Retro Intro
     */
    TT_RETRO_INTRO("tt-retro-intro.png", "Retro Intro", 109, 109, "Bilal Ketab", "http://www.twitter.com/Creartinc"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Rice Paper
     */
    TT_RICE_PAPER("tt-rice-paper.png", "Rice Paper", 500, 500, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Rice Paper #2
     */
    TT_RICE_PAPER_2("tt-rice-paper-2.png", "Rice Paper #2", 485, 485, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Rice Paper #3
     */
    TT_RICE_PAPER_3("tt-rice-paper-3.png", "Rice Paper #3", 250, 250, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Robots
     */
    TT_ROBOTS("tt-robots.png", "Robots", 200, 200, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Rocky Wall
     */
    TT_ROCKY_WALL("tt-rocky-wall.png", "Rocky Wall", 500, 500, "Projecteightyfive", "http://projecteightyfive.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Rough Cloth
     */
    TT_ROUGH_CLOTH("tt-rough-cloth.png", "Rough Cloth", 320, 320, "Bartosz Kaszubowski", "http://twitter.com/simek"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Rough Cloth (Light)
     */
    TT_ROUGH_CLOTH_LIGHT("tt-rough-cloth-light.png", "Rough Cloth (Light)", 320, 320, "Bartosz Kaszubowski", "http://twitter.com/simek"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Rough Diagonal
     */
    TT_ROUGH_DIAGONAL("tt-rough-diagonal.png", "Rough Diagonal", 256, 256, "Jorick van Hees", "http://jorickvanhees.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Rubber Grip
     */
    TT_RUBBER_GRIP("tt-rubber-grip.png", "Rubber Grip", 5, 20, "Sinisha", "http://be.net/pixilated"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Sandpaper
     */
    TT_SANDPAPER("tt-sandpaper.png", "Sandpaper", 348, 500, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Satin Weave
     */
    TT_SATIN_WEAVE("tt-satin-weave.png", "Satin Weave", 24, 12, "Merrin Macleod", "http://www.merxplat.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Scribble Light
     */
    TT_SCRIBBLE_LIGHT("tt-scribble-light.png", "Scribble Light", 304, 306, "Tegan Male", "http://thelovelyfox.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Shattered (Dark)
     */
    TT_SHATTERED_DARK("tt-shattered-dark.png", "Shattered (Dark)", 500, 500, "Luuk van Baars", "http://luukvanbaars.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Shattered (Light)
     */
    TT_SHATTERED_LIGHT("tt-shattered-light.png", "Shattered (Light)", 500, 500, "Luuk van Baars", "http://luukvanbaars.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Shine Caro
     */
    TT_SHINE_CARO("tt-shine-caro.png", "Shine Caro", 9, 9, "mediumidee", "http://www.mediumidee.de"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Shine Dotted
     */
    TT_SHINE_DOTTED("tt-shine-dotted.png", "Shine Dotted", 6, 5, "mediumidee", "http://www.mediumidee.de"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Shley Tree 1
     */
    TT_SHLEY_TREE_1("tt-shley-tree-1.png", "Shley Tree 1", 300, 409, "Derek Ramsey", "http://en.wikipedia.org/wiki/User:Ram-Man"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Shley Tree 2
     */
    TT_SHLEY_TREE_2("tt-shley-tree-2.png", "Shley Tree 2", 400, 414, "Mike Hearn", "http://www.mikehearn.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Silver Scales
     */
    TT_SILVER_SCALES("tt-silver-scales.png", "Silver Scales", 40, 40, "Alex Parker", "http://twitter.com/misterparker"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Simple Dashed
     */
    TT_SIMPLE_DASHED("tt-simple-dashed.png", "Simple Dashed", 14, 14, "Venam", "http://venam.1.ai"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Simple Horizontal Light
     */
    TT_SIMPLE_HORIZONTAL_LIGHT("tt-simple-horizontal-light.png", "Simple Horizontal Light", 4, 4, "Fabricio"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Skeletal Weave
     */
    TT_SKELETAL_WEAVE("tt-skeletal-weave.png", "Skeletal Weave", 25, 25, "Angelica", "http://fleeting_days.livejournal.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Skewed Print
     */
    TT_SKEWED_PRINT("tt-skewed-print.png", "Skewed Print", 330, 320, "Hendrik Lammers", "http://www.hendriklammers.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Skin Side Up
     */
    TT_SKIN_SIDE_UP("tt-skin-side-up.png", "Skin Side Up", 320, 360, "Hendrik Lammers", "http://www.hendriklammers.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Skulls
     */
    TT_SKULLS("tt-skulls.png", "Skulls", 400, 400, "Adam"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Slash It
     */
    TT_SLASH_IT("tt-slash-it.png", "Slash It", 9, 9, "Venam", "http://venam.1.ai"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Small Crackle Bright
     */
    TT_SMALL_CRACKLE_BRIGTH("tt-small-crackle-bright.png", "Small Crackle Bright", 14, 14, "Markus Tinner", "http://www.markustinner.ch"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Small Crosses
     */
    TT_SMALL_CROSSES("tt-small-crosses.png", "Small Crosses", 10, 10, "Ian Dmitry"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Smooth Wall (Dark)
     */
    TT_SMOOTH_WALL_DARK("tt-smooth-wall-dark.png", "Smooth Wall (Dark)", 358, 358, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Smooth Wall (Light)
     */
    TT_SMOOTH_WALL_LIGHT("tt-smooth-wall-light.png", "Smooth Wall (Light)", 358, 358, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Sneaker Mesh Fabric
     */
    TT_SNEAKER_MESH_FABRIC("tt-sneaker-mesh-fabric.png", "Sneaker Mesh Fabric", 150, 111, "Victor Bejar", "http://victorbejar.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Snow
     */
    TT_SNOW("tt-snow.png", "Snow", 500, 500, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Soft Circle Scales
     */
    TT_SOFT_CIRCLE_SCALES("tt-soft-circle-scales.png", "Soft Circle Scales", 256, 56, "Ian Soper", "http://iansoper.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Soft Kill
     */
    TT_SOFT_KILL("tt-soft-kill.png", "Soft Kill", 28, 48, "Factorio.us Collective", "http://www.factorio.us"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Soft Pad
     */
    TT_SOFT_PAD("tt-soft-pad.png", "Soft Pad", 8, 8, "Badhon Ebrahim", "http://dribbble.com/graphcoder"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Soft Wallpaper
     */
    TT_SOFT_WALLPAPER("tt-soft-wallpaper.png", "Soft Wallpaper", 666, 666, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Solid
     */
    TT_SOLID("tt-solid.png", "Solid", 500, 500, "Hendrik Lammers", "http://www.hendriklammers.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Sos
     */
    TT_SOS("tt-sos.png", "Sos", 25, 25, "JBasoo", "https://twitter.com/JBasoo"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Sprinkles
     */
    TT_SPRINKLES("tt-sprinkles.png", "Sprinkles", 10, 5, "Rebecca Litt", "http://yellowmangodesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Squairy
     */
    TT_SQUAIRY("tt-squairy.png", "Squairy", 200, 200, "Tia Newbury"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Squared Metal
     */
    TT_SQUARED_METAL("tt-squared-metal.png", "Squared Metal", 132, 132, "doot0", "http://twitter.com/doot0"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Squares
     */
    TT_SQUARES("tt-squares.png", "Squares", 32, 32, "Jaromir Kavan", "http://www.toshtak.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Stacked Circles
     */
    TT_STACKED_CIRCLES("tt-stacked-circles.png", "Stacked Circles", 9, 9, "Saqib", "http://www.960development.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Stardust
     */
    TT_STARDUST("tt-stardust.png", "Stardust", 798, 798, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Starring
     */
    TT_STARRING("tt-starring.png", "Starring", 35, 39, "Agus Riyadi", "http://logosmile.net/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Stitched Wool
     */
    TT_STITCHED_WOOL("tt-stitched-wool.png", "Stitched Wool", 224, 128, "Badhon Ebrahim", "http://dribbble.com/graphcoder"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Strange Bullseyes
     */
    TT_STRANGE_BULLSEYES("tt-strange-bullseyes.png", "Strange Bullseyes", 300, 300, "Christopher Buecheler", "http://cwbuecheler.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Straws
     */
    TT_STRAWS("tt-straws.png", "Straws", 16, 16, "Pavel", "http://evaluto.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Stressed Linen
     */
    TT_STRESSED_LINEN("tt-stressed-linen.png", "Stressed Linen", 256, 256, "Jordan Pittman"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Bartosz Kaszubowski
     */
    TT_STUCCO("tt-stucco.png", "Stucco", 250, 249, "Bartosz Kaszubowski", "http://twitter.com/#!/simek"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Subtlenet
     */
    TT_SUBTLENET("tt-subtlenet.png", "Subtlenet", 60, 60, "Designova", "http://www.designova.net"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Subtle Carbon
     */
    TT_SUBTLE_CARBON("tt-subtle-carbon.png", "Subtle Carbon", 18, 15, "Designova", "http://www.designova.net"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Subtle Dark Vertical
     */
    TT_SUBTLE_DARK_VERTICAL("tt-subtle-dark-vertical.png", "Subtle Dark Vertical", 40, 40, "Cody L", "http://tirl.tk/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Subtle Dots
     */
    TT_SUBTLE_DOTS("tt-subtle-dots.png", "Subtle Dots", 27, 15, "Designova", "http://www.designova.net"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Subtle Freckles
     */
    TT_SUBTLE_FRECKLES("tt-subtle-freckles.png", "Subtle Freckles", 198, 198, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Subtle Grey
     */
    TT_SUBTLE_GREY("tt-subtle-grey.png", "Subtle Grey", 397, 322, "Haris Sumic"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Subtle Grunge
     */
    TT_SUBTLE_GRUNGE("tt-subtle-grunge.png", "Subtle Grunge", 400, 400, "Breezi", "http://breezi.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Subtle Stripes
     */
    TT_SUBTLE_STRIPES("tt-subtle-stripes.png", "Subtle Stripes", 40, 40, "Raasa", "http://cargocollective.com/raasa"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Subtle Surface
     */
    TT_SUBTLE_SURFACE("tt-subtle-surface.png", "Subtle Surface", 16, 8, "Designova", "http://www.designova.net"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Subtle White Feathers
     */
    TT_SUBTLE_WHITE_FEATHERS("tt-subtle-white-feathers.png", "Subtle White Feathers", 500, 333, "Viahorizon", "http://therapywarsaw.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Subtle Zebra 3D
     */
    TT_SUBTLE_ZEBRA_3D("tt-subtle-zebra-3d.png", "Subtle Zebra 3D", 121, 38, "Mike Warner", "http://www.miketheindian.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Swirl
     */
    TT_SWIRL("tt-swirl.png", "Swirl", 200, 200, "Peter Chon", "http://peterchondesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Tactile Noise (Dark)
     */
    TT_TACTILE_NOISE_DARK("tt-tactile-noise-dark.png", "Tactile Noise (Dark)", 48, 48, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Tactile Noise (Light)
     */
    TT_TACTILE_NOISE_LIGHT("tt-tactile-noise-light.png", "Tactile Noise (Light)", 48, 48, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Tapestry
     */
    TT_TAPESTRY("tt-tapestry.png", "Tapestry", 72, 61, "Pixeden", "http://www.pixeden.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Tasky
     */
    TT_TASKY("tt-tasky.png", "Tasky", 10, 10, "Michal Chovanec", "http://michalchovanec.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Tex2Res1
     */
    TT_TEX2RES1("tt-tex2res1.png", "Tex2Res1", 500, 500, "Janos Koos", "http://joxadesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Tex2Res2
     */
    TT_TEX2RES2("tt-tex2res2.png", "Tex2Res2", 500, 500, "Janos Koos", "http://joxadesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Tex2Res3
     */
    TT_TEX2RES3("tt-tex2res3.png", "Tex2Res3", 500, 500, "Janos Koos", "http://joxadesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Tex2Res4
     */
    TT_TEX2RES4("tt-tex2res4.png", "Tex2Res4", 500, 500, "Janos Koos", "http://joxadesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Tex2Res5
     */
    TT_TEX2RES5("tt-tex2res5.png", "Tex2Res5", 500, 500, "Janos Koos", "http://joxadesign.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Textured Paper
     */
    TT_TEXTURED_PAPER("tt-textured-paper.png", "Textured Paper", 500, 500, "Stephen Gilbert", "http://stephen.io"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Textured Stripes
     */
    TT_TEXTURED_STRIPES("tt-textured-stripes.png", "Textured Stripes", 256, 256, "V Hartikainen", "http://tiled-bg.blogspot.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Texturetastic Gray
     */
    TT_TEXTURETASTIC_GRAY("tt-texturetastic-gray.png", "Texturetastic Gray", 476, 476, "Adam Pickering", "http://www.adampickering.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Laura Gilbert Gilardenghi
     */
    TT_TICKS("tt-ticks.png", "Ticks", 400, 400, "Laura Gilbert Gilardenghi", "http://rossomenta.blogspot.it/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Tileable Wood
     */
    TT_TILEABLE_WOOD("tt-tileable-wood.png", "Tileable Wood", 400, 317, "Elemis", "http://elemisfreebies.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Tileable Wood Colored
     */
    TT_TILEABLE_WOOD_COLORED("tt-tileable-wood-colored.png", "Tileable Wood Colored", 400, 317, "Elemis", "http://elemisfreebies.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Tiny Grid
     */
    TT_TINY_GRID("tt-tiny-grid.png", "Tiny Grid", 26, 26, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Translucent Fibres
     */
    TT_TRANSLUCENT_FIBRES("tt-translucent-fibres.png", "Translucent Fibres", 16, 16, "Angelica", "http://fleeting_days.livejournal.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Transparent Square Tiles
     */
    TT_TRANSPARENT_SQUARE_TILES("tt-transparent-square-tiles.png", "Transparent Square Tiles", 252, 230, "Nathan Spady", "http://nspady.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Tree Bark
     */
    TT_TREE_BARK("tt-tree-bark.png", "Tree Bark", 350, 350, "GetDiscount", "http://getdiscount.co.uk/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Triangles
     */
    TT_TRIANGLES("tt-triangles.png", "Triangles", 33, 36, "Ivan Ginev", "http://coggraphics.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Triangles 2
     */
    TT_TRIANGLES_2("tt-triangles-2.png", "Triangles 2", 72, 72, "Pixeden", "http://www.pixeden.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Triangular
     */
    TT_TRIANGULAR("tt-triangular.png", "Triangular", 60, 60, "Dax Kieran", "http://daxkieran.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Tweed
     */
    TT_TWEED("tt-tweed.png", "Tweed", 200, 200, "Simon Leo"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Twinkle Twinkle
     */
    TT_TWINKLE_TWINKLE("tt-twinkle-twinkle.png", "Twinkle Twinkle", 360, 300, "Badhon Ebrahim", "http://dribbble.com/graphcoder"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Txture
     */
    TT_TXTURE("tt-txture.png", "Txture", 400, 300, "Anatoli Nicolae", "http://designchomp.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Type
     */
    TT_TYPE("tt-type.png", "Type", 200, 200, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Use Your Illusion
     */
    TT_USE_YOUR_ILLUSION("tt-use-your-illusion.png", "Use Your Illusion", 54, 58, "Mohawk Studios", "http://www.mohawkstudios.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Vaio
     */
    TT_VAIO("tt-vaio.png", "Vaio", 37, 28, "Zigzain", "http://www.zigzain.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Vertical Cloth
     */
    TT_VERTICAL_CLOTH("tt-vertical-cloth.png", "Vertical Cloth", 399, 400, "Krisp Designs", "http://dribbble.com/krisp"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Vichy
     */
    TT_VICHY("tt-vichy.png", "Vichy", 70, 70, "Olivier Pineda", "http://www.olivierpineda.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Vintage Speckles
     */
    TT_VINTAGE_SPECKLES("tt-vintage-speckles.png", "Vintage Speckles", 400, 300, "David Pomfret", "http://simpleasmilk.co.uk"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Wall #4 Light
     */
    TT_WALL_4_LIGHT("tt-wall-4-light.png", "Wall #4 Light", 300, 300, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Washi
     */
    TT_WASHI("tt-washi.png", "Washi", 100, 100, "Carolynne", "http://www.sweetstudio.co.uk"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Wavecut
     */
    TT_WAVECUT("tt-wavecut.png", "Wavecut", 162, 15, "Ian Soper", "http://iansoper.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Wave Grid
     */
    TT_WAVE_GRID("tt-wave-grid.png", "Wave Grid", 100, 100, "DomainsInfo", "http://www.domainsinfo.org/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Weave
     */
    TT_WEAVE("tt-weave.png", "Weave", 35, 31, "Catherine", "http://wellterned.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Wet Snow
     */
    TT_WET_SNOW("tt-wet-snow.png", "Wet Snow", 250, 250, "Kerstkaarten", "http://www.fotokaarten.nl/kerst.html"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Whitey
     */
    TT_WHITEY("tt-whitey.png", "Whitey", 654, 654, "Ant Eksiler", "http://www.turkhitbox.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Bed Sheet
     */
    TT_WHITE_BED_SHEET("tt-white-bed-sheet.png", "White Bed Sheet", 54, 54, "Badhon Ebrahim", "http://dribbble.com/graphcoder"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Brick Wall
     */
    TT_WHITE_BRICK_WALL("tt-white-brick-wall.png", "White Brick Wall", 24, 16, "Listvetra", "http://www.listvetra.ru"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Brushed
     */
    TT_WHITE_BRUSHED("tt-white-brushed.png", "White Brushed", 114, 114, "Andre Schouten", "http://uniqappz.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Carbon
     */
    TT_WHITE_CARBON("tt-white-carbon.png", "White Carbon", 8, 8, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Carbonfiber
     */
    TT_WHITE_CARBONFIBER("tt-white-carbonfiber.png", "White Carbonfiber", 4, 4, "Badhon Ebrahim", "http://dribbble.com/graphcoder"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Diamond (Dark)
     */
    TT_WHITE_DIAMOND_DARK("tt-white-diamond-dark.png", "White Diamond (Dark)", 128, 224, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Diamond
     */
    TT_WHITE_DIAMOND_LIGHT("tt-white-diamond-light.png", "White Diamond", 128, 224, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Leather
     */
    TT_WHITE_LEATHER("tt-white-leather.png", "White Leather", 300, 300, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Linen
     */
    TT_WHITE_LINEN("tt-white-linen.png", "White Linen", 400, 300, "Fabian Schultz", "http://fabianschultz.de/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Paperboard
     */
    TT_WHITE_PAPERBOARD("tt-white-paperboard.png", "White Paperboard", 256, 252, "Chaos"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Plaster
     */
    TT_WHITE_PLASTER("tt-white-plaster.png", "White Plaster", 300, 300, "Phil Maurer", "http://aurer.co.uk"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile:White Sand 
     */
    TT_WHITE_SAND("tt-white-sand.png", "White Sand", 211, 211, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Texture
     */
    TT_WHITE_TEXTURE("tt-white-texture.png", "White Texture", 102, 102, "Dmitry"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Tiles
     */
    TT_WHITE_TILES("tt-white-tiles.png", "White Tiles", 800, 250, "Another One", "http://www.anotherone.fr/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Wall
     */
    TT_WHITE_WALL("tt-white-wall.png", "White Wall", 800, 600, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Wall 3
     */
    TT_WHITE_WALL_3("tt-white-wall-3.png", "White Wall 3", 150, 150, "Viahorizon", "http://centrumpar.pl/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Wall 3[2]
     */
    TT_WHITE_WALL_3_2("tt-white-wall-3-2.png", "White Wall 3[2]", 500, 500, "Luca", "http://skymbu.info/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: White Wave
     */
    TT_WHITE_WAVE("tt-white-wave.png", "White Wave", 23, 12, "Rohit Arun Rao"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Wide Rectangles
     */
    TT_WIDE_RECTANGLES("tt-wide-rectangles.png", "Wide Rectangles", 32, 14, "Petr Sulc", "http://www.petrsulc.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Wild Flowers
     */
    TT_WILD_FLOWERS("tt-wild-flowers.png", "Wild Flowers", 350, 350, "Themes Tube", "http://themestube.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Wild Oliva
     */
    TT_WILD_OLIVA("tt-wild-oliva.png", "Wild Oliva", 198, 200, "Badhon Ebrahim", "http://dribbble.com/graphcoder"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Wine Cork
     */
    TT_WINE_CORK("tt-wine-cork.png", "Wine Cork", 300, 300, "Atle Mo", "http://atle.co/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Wood
     */
    TT_WOOD("tt-wood.png", "Wood", 700, 700, "Cloaks", "http://cloaks.deviantart.com/"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Wood Pattern
     */
    TT_WOOD_PATTERN("tt-wood-pattern.png", "Wood Pattern", 203, 317, "Alexey Usoltsev"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Worn Dots
     */
    TT_WORN_DOTS("tt-worn-dots.png", "Worn Dots", 200, 200, "Matt McDaniel", "http://mattmcdaniel.me"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Woven
     */
    TT_WOVEN("tt-woven.png", "Woven", 42, 42, "Max Rudberg", "http://www.maxthemes.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Woven (Light)
     */
    TT_WOVEN_LIGHT("tt-woven-light.png", "Woven (Light)", 42, 42, "Max Rudberg", "http://www.maxthemes.com"), // NOI18N
    
    /**
     * The <code>Java</code> representation from the tile: Xv
     */
    TT_XV("tt-xv.png", "Xv", 294, 235, "Lasma", "http://www.oddfur.com"), // NOI18N

    /**
     * The <code>Java</code> representation from the tile: 
     */
    TT_ZIG_ZAG("tt-zig-zag.png", "Zig Zag", 10, 10, "Dmitriy Prodchenko", "http://www.behance.net/dmpr0"); // NOI18N

    private final double height;
    private final double width;

    private final String autor;
    private final String autorUrl;
    private final String imageName;
    private final String title;

    TransparentTexturesTile(
            final String name, final String header,
            final double width, final double height,
            final String autor
    ) {
        this(name, header, width, height, autor, ""); // NOI18N
    }

    TransparentTexturesTile(
            final String imageName, final String title,
            final double width, final double height,
            final String autor, final String autorUrl
    ) {
        this.imageName = imageName;
        this.title = title;
        this.width = width;
        this.height = height;
        this.autor = autor;
        this.autorUrl = autorUrl;
    }

    @Override
    public String getAutor() {
        return autor;
    }

    @Override
    public String getAutorUrl() {
        return autorUrl;
    }

    @Override
    public double getHeight() {
        return height;
    }

    @Override
    public String getImageName() {
        return imageName;
    }

    @Override
    public String getTitle() {
        return title;
    }

    @Override
    public double getWidth() {
        return width;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder();
        sb.append("Tile ["); // NOI18N
        sb.append("imageName=").append(this.getImageName()); // NOI18N
        sb.append(", "); // NOI18N
        sb.append("title=").append(this.getTitle()); // NOI18N
        sb.append(", "); // NOI18N
        sb.append("w=").append(this.getWidth()); // NOI18N
        sb.append(", "); // NOI18N
        sb.append("h=").append(this.getHeight()); // NOI18N
        sb.append(", "); // NOI18N
        sb.append("autor=").append(this.getAutor()); // NOI18N
        
        final String autorUrl = this.getAutorUrl();
        if (
                (autorUrl != null)
                && (!autorUrl.isEmpty())
        ) {
            sb.append(", "); // NOI18N
            sb.append("autorUrl=").append(autorUrl); // NOI18N
        }
                
        sb.append("]"); // NOI18N
        
        return sb.toString();
    }
    
}
